@@ -1,5 +1,5 @@
 # pROC: Tools Receiver operating characteristic (ROC curves) with
-# (partial) area under the curve, confidence intervals and comparison. 
+# (partial) area under the curve, confidence intervals and comparison.
 # Copyright (C) 2010-2014 Xavier Robin, Alexandre Hainard, Natacha Turck,
 # Natalia Tiberti, Frédérique Lisacek, Jean-Charles Sanchez
 # and Markus Müller
@@ -22,69 +22,70 @@ ci <- function(...) {
 }
 
 ci.formula <- function(formula, data, ...) {
-	data.missing <- missing(data)
-	roc.data <- roc.utils.extract.formula(formula, data, ..., 
-										  data.missing = data.missing,
-										  call = match.call())
-	if (length(roc.data$predictor.name) > 1) {
-		stop("Only one predictor supported in 'ci'.")
-	}
-	response <- roc.data$response
-	predictor <- roc.data$predictors[, 1]
-	ci.roc(roc(response, predictor, ...), ...)
+  data.missing <- missing(data)
+  roc.data <- roc_utils_extract_formula(formula, data, ...,
+    data.missing = data.missing,
+    call = match.call()
+  )
+  if (length(roc.data$predictor.name) > 1) {
+    stop("Only one predictor supported in 'ci'.")
+  }
+  response <- roc.data$response
+  predictor <- roc.data$predictors[, 1]
+  ci.roc(roc(response, predictor, ...), ...)
 }
 
 ci.default <- function(response, predictor, ...) {
-	roc <- roc.default(response, predictor, ci = FALSE, ...)
-	if (methods::is(roc, "smooth.roc")) {
-		return(ci.roc(smooth.roc = roc, ...))
-	}
-	else {
-		return(ci.roc(roc = roc, ...))
-	}
+  roc <- roc.default(response, predictor, ci = FALSE, ...)
+  if (methods::is(roc, "smooth.roc")) {
+    return(ci.roc(smooth.roc = roc, ...))
+  } else {
+    return(ci.roc(roc = roc, ...))
+  }
 }
 
 ci.smooth.roc <- function(smooth.roc, of = c("auc", "sp", "se", "coords"), ...) {
   of <- match.arg(of)
-  
-  if (of == "auc")
+
+  if (of == "auc") {
     ci <- ci.auc.smooth.roc(smooth.roc, ...)
-  else if (of == "sp")
+  } else if (of == "sp") {
     ci <- ci.sp.smooth.roc(smooth.roc, ...)
-  else if (of == "se")
+  } else if (of == "se") {
     ci <- ci.se.smooth.roc(smooth.roc, ...)
-  else if (of == "coords")
-  	ci <- ci.coords.smooth.roc(smooth.roc, ...)
-  else
-  	stop(sprintf("Unknown 'of' for CI: %s", of))
+  } else if (of == "coords") {
+    ci <- ci.coords.smooth.roc(smooth.roc, ...)
+  } else {
+    stop(sprintf("Unknown 'of' for CI: %s", of))
+  }
 
   return(ci)
 }
 
 ci.roc <- function(roc, of = c("auc", "thresholds", "sp", "se", "coords"), ...) {
   of <- match.arg(of)
-  
-  if (of == "auc")
+
+  if (of == "auc") {
     ci <- ci.auc.roc(roc, ...)
-  else if (of == "thresholds")
+  } else if (of == "thresholds") {
     ci <- ci.thresholds.roc(roc, ...)
-  else if (of == "sp")
+  } else if (of == "sp") {
     ci <- ci.sp.roc(roc, ...)
-  else if (of == "se")
+  } else if (of == "se") {
     ci <- ci.se.roc(roc, ...)
-  else if (of == "coords")
-  	ci <- ci.coords.roc(roc, ...)
-  else
-  	stop(sprintf("Unknown 'of' for CI: %s", of))
+  } else if (of == "coords") {
+    ci <- ci.coords.roc(roc, ...)
+  } else {
+    stop(sprintf("Unknown 'of' for CI: %s", of))
+  }
 
   return(ci)
 }
 
 ci.multiclass.roc <- function(multiclass.roc, of = "auc", ...) {
-	stop("CI of a multiclass ROC curve not implemented")
+  stop("CI of a multiclass ROC curve not implemented")
 }
 
 ci.multiclass.auc <- function(multiclass.auc, of = "auc", ...) {
-	stop("CI of a multiclass AUC not implemented")
+  stop("CI of a multiclass AUC not implemented")
 }
-
